Crate didi_file_format

Crate didi_file_format 

Functions

read_didi
Reads data from a file, checking metadata for the presence of a search string
rle_decode
Decodes data from Run-Length Encoding
rle_encode
Encodes data using Run-Length Encoding
sniffer
Sniffs the file to determine what string is stored in the metadata
write_didi
Writes data to a file with metadata about the presence of a search string