Functions
- read_
didi - Reads data from a file, checking metadata for the presence of a search string
- rle_
decode - Decodes data from Run-Length Encoding
- rle_
encode - Encodes data using Run-Length Encoding
- sniffer
- Sniffs the file to determine what string is stored in the metadata
- write_
didi - Writes data to a file with metadata about the presence of a search string